@@ -28,3 +28,19 @@ fn is_process_active(process_id: u32) -> bool {
 
     system.get_process(process_id).is_some()
 }
+
+/// Gets the parent process id from the CLI arguments.
+///
+/// The dprint cli will provide a `--parent-pid <value>` flag to specify the parent PID.
+pub fn get_parent_process_id_from_cli_args() -> Option<u32> {
+    let args: Vec<String> = std::env::args().collect();
+    for i in 0..args.len() {
+        if args[i] == "--parent-pid" {
+            if let Some(parent_pid) = args.get(i + 1) {
+                return parent_pid.parse::<u32>().map(Some).unwrap_or(None);
+            }
+        }
+    }
+
+    return None;
+}
